==> explainaboard-0.7.16-py2.py3-none-any.whl: explainaboard/tests/test_loaders.py <==
from unittest import TestCase
from explainaboard import TaskType, FileType, Source, get_loader
from explainaboard.tests.utils import load_file_as_str
from explainaboard.loaders.loader import Loader
import pathlib
import os

artifacts_path = os.path.dirname(pathlib.Path(__file__)) + "/artifacts/"


class BaseLoaderTests(TestCase):
    def test_load_in_memory_tsv(self):
        loader = Loader(
            Source.in_memory,
            FileType.tsv,
            load_file_as_str(f"{artifacts_path}sys_out1.tsv"),
        )
        samples = [sample for sample in loader._load_raw_data_points()]
        self.assertEqual(len(samples), 10)
        self.assertEqual(len(samples[0]), 3)


class TextClassificationLoader(TestCase):
    def test_load_in_memory_tsv(self):
        loader = get_loader(
            TaskType.text_classification,
            Source.in_memory,
            FileType.tsv,
            load_file_as_str(f"{artifacts_path}sys_out1.tsv"),
        )
        data = loader.load()
        self.assertEqual(len(data), 10)
        self.assertListEqual(
            list(data[0].keys()), ["id", "text", "true_label", "predicted_label"]
        )


class QASquadLoader(TestCase):
    def test_load_json(self):
        loader = get_loader(
            TaskType.extractive_qa_squad,
            Source.local_filesystem,
            FileType.json,
            f"{artifacts_path}test-qa-squad.json",
        )
        data = loader.load()
        # print(data[0].keys())
        # print(len(data))
        self.assertEqual(len(data), 1190)
        self.assertListEqual(
            list(data[0].keys()),
            ['title', 'context', 'question', 'id', 'true_answers', 'predicted_answer'],
        )


class SummSquadLoader(TestCase):
    def test_load_json(self):
        loader = get_loader(
            TaskType.summarization,
            Source.local_filesystem,
            FileType.tsv,
            f"{artifacts_path}test-summ.tsv",
        )
        data = loader.load()
        # print(data[0].keys())
        # print(len(data))
        self.assertEqual(len(data), 70)

==> explainaboard-0.8.6-py2.py3-none-any.whl: explainaboard/tests/test_loaders.py <==
import os
import pathlib
from unittest import TestCase

from explainaboard import FileType, get_loader, Source, TaskType
from explainaboard.loaders.file_loader import FileLoaderField, TSVFileLoader
from explainaboard.loaders.loader import Loader
from explainaboard.tests.utils import load_file_as_str

artifacts_path = os.path.dirname(pathlib.Path(__file__)) + "/artifacts/"


class BaseLoaderTests(TestCase):
    def test_load_in_memory_tsv(self):
        loader = Loader(
            load_file_as_str(f"{artifacts_path}sys_out1.tsv"),
            Source.in_memory,
            FileType.tsv,
            {
                FileType.tsv: TSVFileLoader(
                    [FileLoaderField(0, "field0", str)], use_idx_as_id=True
                )
            },
        )
        samples = [sample for sample in loader.load()]
        self.assertEqual(len(samples), 10)
        self.assertEqual(set(samples[0].keys()), {"id", "field0"})


class FileLoaderTests(TestCase):
    def test_tsv_validation(self):
        self.assertRaises(
            ValueError,
            lambda: TSVFileLoader(
                [FileLoaderField("0", "field0", str)], use_idx_as_id=True
            ),
        )


class TextClassificationLoader(TestCase):
    def test_load_in_memory_tsv(self):
        loader = get_loader(
            TaskType.text_classification,
            load_file_as_str(f"{artifacts_path}sys_out1.tsv"),
            Source.in_memory,
            FileType.tsv,
        )
        data = loader.load()
        self.assertEqual(len(data), 10)
        self.assertEqual(
            set(data[0].keys()), {"id", "text", "true_label", "predicted_label"}
        )


class QASquadLoader(TestCase):
    def test_load_json(self):
        loader = get_loader(
            TaskType.question_answering_extractive,
            f"{artifacts_path}test-qa-squad.json",
            Source.local_filesystem,
            FileType.json,
        )
        data = loader.load()
        self.assertEqual(len(data), 5)


class SummSquadLoader(TestCase):
    def test_load_json(self):
        loader = get_loader(
            TaskType.summarization,
            f"{artifacts_path}test-summ.tsv",
            Source.local_filesystem,
            FileType.tsv,
        )
        data = loader.load()
        self.assertEqual(len(data), 70)
